Contributors
============

Development & Technical Support
-------------------------------

-   **Thomas Mansencal**, *Visual Effects Artist*

    Project coordination, overall development.

-   **Michael Mauderer**, *HCI Researcher @ University of St Andrews*

    Colour appearance models, overall development.

-   **Michael Parsons**, *Colour Scientist @ The Moving Picture Company*

    Continuous technical support.

Acknowledgements
----------------

-   **Paul Centore**, *Mathematician & Colour Scientist*

    Matlab *Munsell Renotation System* implementation.

-   **Yoshi Ohno**, *Mathematician & Colour Scientist*.

    *Ohno (2013)* correlated colour temperature calculation technical support.

-   **Charles Poynton**, Mathematician & Colour Scientist

    Technical support.

-   **Alex Forsythe**, *Image Engineering Manager @ Academy of Motion Picture Arts and Sciences*

    *ACES RGB IDT* technical support.

-   **Scott Dyer**, *Image Engineering @ Academy of Motion Picture Arts and Sciences*

    *ACES RGB IDT* technical support.

Special Mentions
----------------

-   **Aurélia Sellier**, *Line Producer @ Cube Creative*

About
-----

| **Colour** by Colour Developers - 2013 - 2014
| Copyright © 2013 - 2014 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour <http://github.com/colour-science/colour>`_
